<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>CustomDialog</name>
    <message>
        <location filename="../dialog.cpp" line="16"/>
        <source>Live environment detected. Please select the root partition of the
 system you want to modify (only Linux partitions are displayed)</source>
        <translation>Распознан сеанс Live системы. Пожалуйста, выберите корневой раздел
системы, которую вы хотите редактировать (отображены только Linux разделы)</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="22"/>
        <source>OK</source>
        <translation>Да</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="23"/>
        <source>Cancel</source>
        <translation>Отменить</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="33"/>
        <source>Options</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="39"/>
        <source>Kernel parameters</source>
        <translation>Параметры ядра</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>Set to &apos;0&apos; to boot immediately without displaying the menu, or to &apos;-1&apos; to wait indefinitely</source>
        <translation>Установите «0» для немедленной загрузки без отображения меню или «-1», чтобы ждать бесконечно</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Menu timeout</source>
        <translation>Таймаут меню</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="75"/>
        <source>Boot to</source>
        <translation>Загрузить</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="82"/>
        <source>Use simplified menu structure without submenus</source>
        <translation>Использовать упрощённое меню, без подменю</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="85"/>
        <source>Use flat menus (no submenus)</source>
        <translation>Использовать плоское меню (без подменю)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="114"/>
        <source>seconds</source>
        <translation>секунд</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="121"/>
        <source>With this option enabled whatever entry you select from the grub boot menu will be saved as the new default for future boots</source>
        <translation>Если этот параметр включен, то любая запись, которую вы выбираете из меню загрузки grub, будет сохранена в качестве нового значения по умолчанию для будущих загрузок</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="124"/>
        <source>Enable saving last boot choice</source>
        <translation>Вкл. сохранение последнего варианта загрузки</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="137"/>
        <source>Background</source>
        <translation>Фон</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="155"/>
        <source>Image</source>
        <translation>Образ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <location filename="../mainwindow.ui" line="270"/>
        <source>Enable theme</source>
        <translation>Включить тему</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>Splash</source>
        <translation>Splash</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Preview</source>
        <translation>Предпросмотр</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="306"/>
        <source>Messages</source>
        <translation>Сообщения</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="312"/>
        <source>Very detailed</source>
        <translation>Очень подробно</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="319"/>
        <source>Detailed (default setting)</source>
        <translation>Подробно (настройка по умолчанию)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="329"/>
        <source>Limited</source>
        <translation>Кратко</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="345"/>
        <source>Display log</source>
        <translation>Просмотр журнала</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="398"/>
        <source>Display help </source>
        <translation>Показать справку</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="401"/>
        <source>Help</source>
        <translation>Справка</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>About this application</source>
        <translation>Об этом приложении</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="443"/>
        <source>About...</source>
        <translation>O...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="450"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="485"/>
        <source>Quit application</source>
        <translation>Выход</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="488"/>
        <location filename="../mainwindow.cpp" line="686"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="495"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="536"/>
        <source>Apply</source>
        <translation>Применить</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="70"/>
        <source>Still running</source>
        <translation>Все еще работает</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="71"/>
        <source>Process still running. Are you sure you want to quit?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="186"/>
        <source>Installing bootsplash, please wait</source>
        <translation>Установка bootsplash, подождите</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="193"/>
        <source>Updating sources</source>
        <translation>Обновление источников</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="195"/>
        <source>Installing</source>
        <translation>Установка</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="199"/>
        <location filename="../mainwindow.cpp" line="338"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="199"/>
        <source>Could not install the bootsplash.</source>
        <translation>Не удалось установить bootsplash</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="294"/>
        <location filename="../mainwindow.cpp" line="344"/>
        <source>Cannot continue</source>
        <translation>Невозможно продолжить</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="294"/>
        <source>Nothing was selected, cannot change boot options. Exiting...</source>
        <translation>Ничего не выбрано, невозможно изменить параметры загрузки. Выход...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="339"/>
        <source>Could not create a temporary folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="345"/>
        <source>Cannot create chroot environment, cannot change boot options. Exiting...</source>
        <translation>Невозможно создать среду chroot, изменить параметры загрузки. Выход ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="577"/>
        <location filename="../mainwindow.cpp" line="879"/>
        <source>Updating configuration, please wait</source>
        <translation>Обновление конфигурации, пожалуйста, подождите</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="626"/>
        <source>Updating initramfs...</source>
        <translation>Обновление initramfs...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="635"/>
        <location filename="../mainwindow.cpp" line="891"/>
        <source>Updating grub...</source>
        <translation>Обновление grub...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="639"/>
        <source>Done</source>
        <translation>Готово</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="639"/>
        <source>Changes have been successfully applied.</source>
        <translation>Изменения были успешно применены.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="650"/>
        <source>About</source>
        <translation>О приложении</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="652"/>
        <source>Version: </source>
        <translation>Версия: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="653"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Программа для выбора общих вариантов запуска</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="655"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="656"/>
        <location filename="../mainwindow.cpp" line="667"/>
        <source>License</source>
        <translation>Лицензия</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="657"/>
        <location filename="../mainwindow.cpp" line="674"/>
        <source>Changelog</source>
        <translation>Список изменений</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="658"/>
        <source>Cancel</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="704"/>
        <source>MX Boot Options</source>
        <translation>MX Опции загрузчика</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="716"/>
        <source>Running in a Virtual Machine</source>
        <translation>Запуск в виртуальной машине</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="717"/>
        <source>You current system is running in a Virtual Machine,
Plymouth bootsplash will work in a limited way, you also won&apos;t be able to preview the theme</source>
        <translation>Текущая система работает на виртуальной машине,
Plymouth bootsplash будет работать ограниченным образом, вы также не сможете просмотреть тему</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="722"/>
        <source>Plymouth packages not installed</source>
        <translation>Plymouth пакет не установлен</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="722"/>
        <source>Plymouth packages are not currently installed.
OK to go ahead and install them?</source>
        <translation>Пакеты Plymouth в настоящее время не установлены.
ОК, чтобы продолжить и установить их?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="743"/>
        <source>Images (*.png *.jpg *.jpeg *.tga)</source>
        <translation>Изображения (*.png *.jpg *.jpeg *.tga)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="843"/>
        <source>Press any key to close</source>
        <translation>Для закрытия нажмите любую клавишу</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="845"/>
        <source>Log not found</source>
        <translation>Лог не найден</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="845"/>
        <source>Could not find log at </source>
        <translation>Не удалось найти журнал</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="858"/>
        <source>Needs reboot</source>
        <translation>Требуется перезагрузка</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="858"/>
        <source>Plymouth was just installed, you might need to reboot before being able to display previews</source>
        <translation>Plymouth только что был установлен, вам может потребоваться перезагрузка, прежде чем вы сможете отображать превью</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="912"/>
        <source>Click to select theme</source>
        <translation>Щелкните для выбора темы</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="46"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Программа для выбора общих вариантов запуска</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="741"/>
        <source>Select image to display in bootloader</source>
        <translation>Выберите изображение для загрузчика</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="922"/>
        <source>Select GRUB theme</source>
        <translation>Выбрать тему GRUB</translation>
    </message>
</context>
</TS>
